@@ -3,7 +3,6 @@
 context("Test that create_icasa() creates a text file")
 test_that("create_icasa() creates a txt file with proper values", {
   skip_on_cran()
-  vcr::use_cassette(name = "create_icasa", {
     create_icasa(
       lonlat = c(151.81, -27.48),
       dates = c("1983-01-01"),
@@ -15,7 +14,6 @@ test_that("create_icasa() creates a txt file with proper values", {
     expect_equal(length(icasa), 16)
     expect_equal(nchar(icasa)[[1]], 47)
     expect_equal(nchar(icasa)[[16]], 73)
-  })
 })
 
 test_that("create_icasa() fails if no dsn or file_out are supplied", {
